==> pocl_1.1.orig.tar.gz: pocl-1.1/lib/kernel/sleef/libm/rename_vec128.h <==
#define xsin Sleef_sind2_u35_intrin
#define xcos Sleef_cosd2_u35_intrin
#define xsincos Sleef_sincosd2_u35_intrin
#define xtan Sleef_tand2_u35_intrin
#define xasin Sleef_asind2_u35_intrin
#define xacos Sleef_acosd2_u35_intrin
#define xatan Sleef_atand2_u35_intrin
#define xatan2 Sleef_atan2d2_u35_intrin
#define xlog Sleef_logd2_u35_intrin
#define xcbrt Sleef_cbrtd2_u35_intrin
#define xsin_u1 Sleef_sind2_u10_intrin
#define xcos_u1 Sleef_cosd2_u10_intrin
#define xsincos_u1 Sleef_sincosd2_u10_intrin
#define xtan_u1 Sleef_tand2_u10_intrin
#define xasin_u1 Sleef_asind2_u10_intrin
#define xacos_u1 Sleef_acosd2_u10_intrin
#define xatan_u1 Sleef_atand2_u10_intrin
#define xatan2_u1 Sleef_atan2d2_u10_intrin
#define xlog_u1 Sleef_logd2_u10_intrin
#define xcbrt_u1 Sleef_cbrtd2_u10_intrin
#define xexp Sleef_expd2_u10_intrin
#define xpow Sleef_powd2_u10_intrin
#define xsinh Sleef_sinhd2_u10_intrin
#define xcosh Sleef_coshd2_u10_intrin
#define xtanh Sleef_tanhd2_u10_intrin
#define xasinh Sleef_asinhd2_u10_intrin
#define xacosh Sleef_acoshd2_u10_intrin
#define xatanh Sleef_atanhd2_u10_intrin
#define xexp2 Sleef_exp2d2_u10_intrin
#define xexp10 Sleef_exp10d2_u10_intrin
#define xexpm1 Sleef_expm1d2_u10_intrin
#define xlog10 Sleef_log10d2_u10_intrin
#define xlog1p Sleef_log1pd2_u10_intrin
#define xsincospi_u05 Sleef_sincospid2_u05_intrin
#define xsincospi_u35 Sleef_sincospid2_u35_intrin
#define xsinpi_u05 Sleef_sinpid2_u05_intrin
#define xcospi_u05 Sleef_cospid2_u05_intrin
#define xldexp Sleef_ldexpd2_intrin
#define xilogb Sleef_ilogbd2_intrin
#define xfma Sleef_fmad2_intrin
#define xsqrt_u05 Sleef_sqrtd2_u05_intrin
#define xsqrt_u35 Sleef_sqrtd2_u35_intrin
#define xhypot_u05 Sleef_hypotd2_u05_intrin
#define xhypot_u35 Sleef_hypotd2_u35_intrin
#define xfabs Sleef_fabsd2_intrin
#define xcopysign Sleef_copysignd2_intrin
#define xfmax Sleef_fmaxd2_intrin
#define xfmin Sleef_fmind2_intrin
#define xfdim Sleef_fdimd2_intrin
#define xtrunc Sleef_truncd2_intrin
#define xfloor Sleef_floord2_intrin
#define xceil Sleef_ceild2_intrin
#define xround Sleef_roundd2_intrin
#define xrint Sleef_rintd2_intrin
#define xnextafter Sleef_nextafterd2_intrin
#define xfrfrexp Sleef_frfrexpd2_intrin
#define xexpfrexp Sleef_expfrexpd2_intrin
#define xfmod Sleef_fmodd2_intrin
#define xmodf Sleef_modfd2_intrin
#define xlgamma_u1 Sleef_lgammad2_u10_intrin
#define xlgamma_r_u1 Sleef_lgamma_rd2_u10_intrin
#define xtgamma_u1 Sleef_tgammad2_u10_intrin
#define xerf_u1 Sleef_erfd2_u10_intrin
#define xerfc_u15 Sleef_erfcd2_u15_intrin

#define xsinf Sleef_sinf4_u35_intrin
#define xcosf Sleef_cosf4_u35_intrin
#define xsincosf Sleef_sincosf4_u35_intrin
#define xtanf Sleef_tanf4_u35_intrin
#define xasinf Sleef_asinf4_u35_intrin
#define xacosf Sleef_acosf4_u35_intrin
#define xatanf Sleef_atanf4_u35_intrin
#define xatan2f Sleef_atan2f4_u35_intrin
#define xlogf Sleef_logf4_u35_intrin
#define xcbrtf Sleef_cbrtf4_u35_intrin
#define xsinf_u1 Sleef_sinf4_u10_intrin
#define xcosf_u1 Sleef_cosf4_u10_intrin
#define xsincosf_u1 Sleef_sincosf4_u10_intrin
#define xtanf_u1 Sleef_tanf4_u10_intrin
#define xasinf_u1 Sleef_asinf4_u10_intrin
#define xacosf_u1 Sleef_acosf4_u10_intrin
#define xatanf_u1 Sleef_atanf4_u10_intrin
#define xatan2f_u1 Sleef_atan2f4_u10_intrin
#define xlogf_u1 Sleef_logf4_u10_intrin
#define xcbrtf_u1 Sleef_cbrtf4_u10_intrin
#define xexpf Sleef_expf4_u10_intrin
#define xpowf Sleef_powf4_u10_intrin
#define xsinhf Sleef_sinhf4_u10_intrin
#define xcoshf Sleef_coshf4_u10_intrin
#define xtanhf Sleef_tanhf4_u10_intrin
#define xasinhf Sleef_asinhf4_u10_intrin
#define xacoshf Sleef_acoshf4_u10_intrin
#define xatanhf Sleef_atanhf4_u10_intrin
#define xexp2f Sleef_exp2f4_u10_intrin
#define xexp10f Sleef_exp10f4_u10_intrin
#define xexpm1f Sleef_expm1f4_u10_intrin
#define xlog10f Sleef_log10f4_u10_intrin
#define xlog1pf Sleef_log1pf4_u10_intrin
#define xsincospif_u05 Sleef_sincospif4_u05_intrin
#define xsincospif_u35 Sleef_sincospif4_u35_intrin
#define xsinpif_u05 Sleef_sinpif4_u05_intrin
#define xcospif_u05 Sleef_cospif4_u05_intrin
#define xldexpf Sleef_ldexpf4_intrin
#define xilogbf Sleef_ilogbf4_intrin
#define xfmaf Sleef_fmaf4_intrin
#define xsqrtf_u05 Sleef_sqrtf4_u05_intrin
#define xsqrtf_u35 Sleef_sqrtf4_u35_intrin
#define xhypotf_u05 Sleef_hypotf4_u05_intrin
#define xhypotf_u35 Sleef_hypotf4_u35_intrin
#define xfabsf Sleef_fabsf4_intrin
#define xcopysignf Sleef_copysignf4_intrin
#define xfmaxf Sleef_fmaxf4_intrin
#define xfminf Sleef_fminf4_intrin
#define xfdimf Sleef_fdimf4_intrin
#define xtruncf Sleef_truncf4_intrin
#define xfloorf Sleef_floorf4_intrin
#define xceilf Sleef_ceilf4_intrin
#define xroundf Sleef_roundf4_intrin
#define xrintf Sleef_rintf4_intrin
#define xnextafterf Sleef_nextafterf4_intrin
#define xfrfrexpf Sleef_frfrexpf4_intrin
#define xexpfrexpf Sleef_expfrexpf4_intrin
#define xfmodf Sleef_fmodf4_intrin
#define xmodff Sleef_modff4_intrin
#define xlgammaf_u1 Sleef_lgammaf4_u10_intrin
#define xlgamma_rf_u1 Sleef_lgamma_rf4_u10_intrin
#define xtgammaf_u1 Sleef_tgammaf4_u10_intrin
#define xerff_u1 Sleef_erff4_u10_intrin
#define xerfcf_u15 Sleef_erfcf4_u15_intrin
/***********************/
#define xlog1p_fast Sleef_log1p_fast_d2_u10_intrin
#define xlog1pf_fast Sleef_log1p_fast_f4_u10_intrin

#define xpown Sleef_pownd2_u10_intrin
#define xpownf Sleef_pownf4_u10_intrin
#define xpowr Sleef_powrd2_u10_intrin
#define xpowrf Sleef_powrf4_u10_intrin

==> pocl_6.0.orig.tar.gz: pocl-6.0/lib/kernel/sleef/libm/rename_vec128.h <==
#define xsin Sleef_sind2_u35_intrin
#define xcos Sleef_cosd2_u35_intrin
#define xsincos Sleef_sincosd2_u35_intrin
#define xtan Sleef_tand2_u35_intrin
#define xasin Sleef_asind2_u35_intrin
#define xacos Sleef_acosd2_u35_intrin
#define xatan Sleef_atand2_u35_intrin
#define xatan2 Sleef_atan2d2_u35_intrin
#define xlog Sleef_logd2_u35_intrin
#define xcbrt Sleef_cbrtd2_u35_intrin
#define xsin_u1 Sleef_sind2_u10_intrin
#define xcos_u1 Sleef_cosd2_u10_intrin
#define xsincos_u1 Sleef_sincosd2_u10_intrin
#define xtan_u1 Sleef_tand2_u10_intrin
#define xasin_u1 Sleef_asind2_u10_intrin
#define xacos_u1 Sleef_acosd2_u10_intrin
#define xatan_u1 Sleef_atand2_u10_intrin
#define xatan2_u1 Sleef_atan2d2_u10_intrin
#define xlog_u1 Sleef_logd2_u10_intrin
#define xcbrt_u1 Sleef_cbrtd2_u10_intrin
#define xexp Sleef_expd2_u10_intrin
#define xpow Sleef_powd2_u10_intrin
#define xsinh Sleef_sinhd2_u10_intrin
#define xcosh Sleef_coshd2_u10_intrin
#define xtanh Sleef_tanhd2_u10_intrin
#define xasinh Sleef_asinhd2_u10_intrin
#define xacosh Sleef_acoshd2_u10_intrin
#define xatanh Sleef_atanhd2_u10_intrin
#define xexp2 Sleef_exp2d2_u10_intrin
#define xexp10 Sleef_exp10d2_u10_intrin
#define xexpm1 Sleef_expm1d2_u10_intrin
#define xlog10 Sleef_log10d2_u10_intrin
#define xlog2 Sleef_log2d2_u10_intrin
#define xlog1p Sleef_log1pd2_u10_intrin
#define xsincospi_u05 Sleef_sincospid2_u05_intrin
#define xsincospi_u35 Sleef_sincospid2_u35_intrin
#define xsinpi_u05 Sleef_sinpid2_u05_intrin
#define xcospi_u05 Sleef_cospid2_u05_intrin
#define xldexp Sleef_ldexpd2_intrin
#define xilogb Sleef_ilogbd2_intrin
#define xfma Sleef_fmad2_intrin
#define xsqrt Sleef_sqrtd2_intrin
#define xsqrt_u05 Sleef_sqrtd2_u05_intrin
#define xsqrt_u35 Sleef_sqrtd2_u35_intrin
#define xhypot_u05 Sleef_hypotd2_u05_intrin
#define xhypot_u35 Sleef_hypotd2_u35_intrin
#define xfabs Sleef_fabsd2_intrin
#define xcopysign Sleef_copysignd2_intrin
#define xfmax Sleef_fmaxd2_intrin
#define xfmin Sleef_fmind2_intrin
#define xfdim Sleef_fdimd2_intrin
#define xtrunc Sleef_truncd2_intrin
#define xfloor Sleef_floord2_intrin
#define xceil Sleef_ceild2_intrin
#define xround Sleef_roundd2_intrin
#define xrint Sleef_rintd2_intrin
#define xnextafter Sleef_nextafterd2_intrin
#define xfrfrexp Sleef_frfrexpd2_intrin
#define xexpfrexp Sleef_expfrexpd2_intrin
#define xfmod Sleef_fmodd2_intrin
#define xmodf Sleef_modfd2_intrin
#define xlgamma_u1 Sleef_lgammad2_u10_intrin
#define xlgamma_r_u1 Sleef_lgamma_rd2_u10_intrin
#define xtgamma_u1 Sleef_tgammad2_u10_intrin
#define xerf_u1 Sleef_erfd2_u10_intrin
#define xerfc_u15 Sleef_erfcd2_u15_intrin

#define xsinf Sleef_sinf4_u35_intrin
#define xcosf Sleef_cosf4_u35_intrin
#define xsincosf Sleef_sincosf4_u35_intrin
#define xtanf Sleef_tanf4_u35_intrin
#define xasinf Sleef_asinf4_u35_intrin
#define xacosf Sleef_acosf4_u35_intrin
#define xatanf Sleef_atanf4_u35_intrin
#define xatan2f Sleef_atan2f4_u35_intrin
#define xlogf Sleef_logf4_u35_intrin
#define xcbrtf Sleef_cbrtf4_u35_intrin
#define xsinf_u1 Sleef_sinf4_u10_intrin
#define xcosf_u1 Sleef_cosf4_u10_intrin
#define xsincosf_u1 Sleef_sincosf4_u10_intrin
#define xtanf_u1 Sleef_tanf4_u10_intrin
#define xasinf_u1 Sleef_asinf4_u10_intrin
#define xacosf_u1 Sleef_acosf4_u10_intrin
#define xatanf_u1 Sleef_atanf4_u10_intrin
#define xatan2f_u1 Sleef_atan2f4_u10_intrin
#define xlogf_u1 Sleef_logf4_u10_intrin
#define xcbrtf_u1 Sleef_cbrtf4_u10_intrin
#define xexpf Sleef_expf4_u10_intrin
#define xpowf Sleef_powf4_u10_intrin
#define xsinhf Sleef_sinhf4_u10_intrin
#define xcoshf Sleef_coshf4_u10_intrin
#define xtanhf Sleef_tanhf4_u10_intrin
#define xasinhf Sleef_asinhf4_u10_intrin
#define xacoshf Sleef_acoshf4_u10_intrin
#define xatanhf Sleef_atanhf4_u10_intrin
#define xexp2f Sleef_exp2f4_u10_intrin
#define xexp10f Sleef_exp10f4_u10_intrin
#define xexpm1f Sleef_expm1f4_u10_intrin
#define xlog10f Sleef_log10f4_u10_intrin
#define xlog2f Sleef_log2f4_u10_intrin
#define xlog1pf Sleef_log1pf4_u10_intrin
#define xsincospif_u05 Sleef_sincospif4_u05_intrin
#define xsincospif_u35 Sleef_sincospif4_u35_intrin
#define xsinpif_u05 Sleef_sinpif4_u05_intrin
#define xcospif_u05 Sleef_cospif4_u05_intrin
#define xldexpf Sleef_ldexpf4_intrin
#define xilogbf Sleef_ilogbf4_intrin
#define xfmaf Sleef_fmaf4_intrin
#define xsqrtf Sleef_sqrtf4_intrin
#define xsqrtf_u05 Sleef_sqrtf4_u05_intrin
#define xsqrtf_u35 Sleef_sqrtf4_u35_intrin
#define xhypotf_u05 Sleef_hypotf4_u05_intrin
#define xhypotf_u35 Sleef_hypotf4_u35_intrin
#define xfabsf Sleef_fabsf4_intrin
#define xcopysignf Sleef_copysignf4_intrin
#define xfmaxf Sleef_fmaxf4_intrin
#define xfminf Sleef_fminf4_intrin
#define xfdimf Sleef_fdimf4_intrin
#define xtruncf Sleef_truncf4_intrin
#define xfloorf Sleef_floorf4_intrin
#define xceilf Sleef_ceilf4_intrin
#define xroundf Sleef_roundf4_intrin
#define xrintf Sleef_rintf4_intrin
#define xnextafterf Sleef_nextafterf4_intrin
#define xfrfrexpf Sleef_frfrexpf4_intrin
#define xexpfrexpf Sleef_expfrexpf4_intrin
#define xfmodf Sleef_fmodf4_intrin
#define xmodff Sleef_modff4_intrin
#define xlgammaf_u1 Sleef_lgammaf4_u10_intrin
#define xlgamma_rf_u1 Sleef_lgamma_rf4_u10_intrin
#define xtgammaf_u1 Sleef_tgammaf4_u10_intrin
#define xerff_u1 Sleef_erff4_u10_intrin
#define xerfcf_u15 Sleef_erfcf4_u15_intrin
/***********************/
#define xlog1p_fast Sleef_log1p_fast_d2_u10_intrin
#define xlog1pf_fast Sleef_log1p_fast_f4_u10_intrin

#define xpown Sleef_pownd2_u10_intrin
#define xpownf Sleef_pownf4_u10_intrin
#define xpowr Sleef_powrd2_u10_intrin
#define xpowrf Sleef_powrf4_u10_intrin
